@@ -28,7 +28,7 @@ class SerialDevice(CommonDeviceInterface):
 
         return self._serial.write(data.encode())
 
-    def receive_output(self) -> str:
+    def receive_output(self, length=1) -> bytes:
         """
         Receive command output through the serial connection.
 
@@ -39,4 +39,4 @@ class SerialDevice(CommonDeviceInterface):
         if self._serial.is_open is False:
             self._serial.open()
 
-        return self._serial.readline().decode()
+        return self._serial.readline()
